@@ -7,16 +7,7 @@ has parts => sub { [] };
 
 sub new {
   my $self = shift->SUPER::new(@_);
-
-  # Default content parser
-  $self->on(
-    read => sub {
-      my ($self, $chunk) = @_;
-      $self->{multipart} .= $chunk;
-      $self->_parse_multipart;
-    }
-  );
-
+  $self->on(read => \&_read);
   return $self;
 }
 
@@ -224,6 +215,12 @@ sub _parse_multipart_preamble {
   return;
 }
 
+sub _read {
+  my ($self, $chunk) = @_;
+  $self->{multipart} .= $chunk;
+  $self->_parse_multipart;
+}
+
 1;
 
 =head1 NAME
