@@ -1,5 +1,5 @@
 package Mojolicious::Command::version;
-use Mojo::Base 'Mojo::Command';
+use Mojo::Base 'Mojolicious::Command';
 
 use Mojo::IOLoop::Server;
 use Mojo::Server::Daemon;
@@ -30,9 +30,9 @@ CORE
   Mojolicious ($Mojolicious::VERSION, $Mojolicious::CODENAME)
 
 OPTIONAL
-  EV                       ($ev)
-  IO::Socket::IP           ($ipv6)
-  IO::Socket::SSL          ($tls)
+  EV              ($ev)
+  IO::Socket::IP  ($ipv6)
+  IO::Socket::SSL ($tls)
 
 EOF
 
@@ -73,7 +73,7 @@ and optional modules.
 =head1 ATTRIBUTES
 
 L<Mojolicious::Command::version> inherits all attributes from
-L<Mojo::Command> and implements the following new ones.
+L<Mojolicious::Command> and implements the following new ones.
 
 =head2 C<description>
 
@@ -91,8 +91,8 @@ Usage information for this command, used for the help screen.
 
 =head1 METHODS
 
-L<Mojolicious::Command::version> inherits all methods from L<Mojo::Command>
-and implements the following new ones.
+L<Mojolicious::Command::version> inherits all methods from
+L<Mojolicious::Command> and implements the following new ones.
 
 =head2 C<run>
 
